pub struct SimBlock<TxReq = TransactionRequest> {
pub block_overrides: Option<BlockOverrides>,
pub state_overrides: Option<StateOverride>,
pub calls: Vec<TxReq>,
}Expand description
Represents a batch of calls to be simulated sequentially within a block. This struct includes block and state overrides as well as the transaction requests to be executed.
Fields
block_overrides: Option<BlockOverrides>Modifications to the default block characteristics.
state_overrides: Option<StateOverride>State modifications to apply before executing the transactions.
calls: Vec<TxReq>A vector of transactions to be simulated.
Implementations
Sourceimpl<TxReq> SimBlock<TxReq>
impl<TxReq> SimBlock<TxReq>
Sourcepub fn with_state_overrides(self, overrides: StateOverride) -> Self
pub fn with_state_overrides(self, overrides: StateOverride) -> Self
Enables state overrides
Sourcepub fn with_block_overrides(self, overrides: BlockOverrides) -> Self
pub fn with_block_overrides(self, overrides: BlockOverrides) -> Self
Enables block overrides
Sourcepub fn extend_calls(self, calls: impl IntoIterator<Item = TxReq>) -> Self
pub fn extend_calls(self, calls: impl IntoIterator<Item = TxReq>) -> Self
Adds multiple calls to the block.
Sourcepub fn block_number_override(&self) -> Option<U256>
pub fn block_number_override(&self) -> Option<U256>
Returns the block’s block number override if it exists.