pub struct Header<H = Header> {
pub hash: BlockHash,
pub inner: H,
pub total_difficulty: Option<U256>,
pub size: Option<U256>,
}Expand description
RPC representation of block header, wrapping a consensus header.
This wraps the consensus header and adds additional fields for RPC.
Fields
hash: BlockHashHash of the block
inner: HInner consensus header.
total_difficulty: Option<U256>Total difficulty
Note: This field is now effectively deprecated: https://github.com/ethereum/execution-apis/pull/570
size: Option<U256>Integer the size of this block in bytes.
Implementations
Sourceimpl<H> Header<H>
impl<H> Header<H>
Sourcepub fn new(inner: H) -> Selfwhere
H: Sealable,
pub fn new(inner: H) -> Selfwhere
H: Sealable,
Create a new Header from a consensus header.
Note: This will compute the hash of the header.
Sourcepub fn from_sealed(header: Sealed<H>) -> Self
pub fn from_sealed(header: Sealed<H>) -> Self
Create a new Header from a sealed consensus header.
Note: This does not set the total difficulty or size of the block.
Sourcepub fn into_sealed(self) -> Sealed<H>
pub fn into_sealed(self) -> Sealed<H>
Consumes the type and returns the Sealed header.
Sourcepub fn into_consensus(self) -> H
pub fn into_consensus(self) -> H
Consumes the type and returns the wrapped consensus header.
Sourcepub fn from_consensus(
header: Sealed<H>,
total_difficulty: Option<U256>,
size: Option<U256>,
) -> Self
pub fn from_consensus( header: Sealed<H>, total_difficulty: Option<U256>, size: Option<U256>, ) -> Self
Create a new Header from a sealed consensus header and additional fields.
Sourcepub const fn with_total_difficulty(self, total_difficulty: Option<U256>) -> Self
pub const fn with_total_difficulty(self, total_difficulty: Option<U256>) -> Self
Set the total difficulty of the block.
Sourceimpl<H: BlockHeader> Header<H>
impl<H: BlockHeader> Header<H>
Sourcepub fn blob_fee(&self) -> Option<u128>
pub fn blob_fee(&self) -> Option<u128>
Returns the blob fee for this block according to the EIP-4844 spec.
Returns None if excess_blob_gas is None
Sourcepub fn next_block_blob_fee(&self, blob_params: BlobParams) -> Option<u128>
pub fn next_block_blob_fee(&self, blob_params: BlobParams) -> Option<u128>
Returns the blob fee for the next block according to the EIP-4844 spec.
Returns None if excess_blob_gas is None.
See also Self::next_block_excess_blob_gas
Sourcepub fn next_block_excess_blob_gas(&self, blob_params: BlobParams) -> Option<u64>
pub fn next_block_excess_blob_gas(&self, blob_params: BlobParams) -> Option<u64>
Calculate excess blob gas for the next block according to the EIP-4844 spec.
Returns a None if no excess blob gas is set, no EIP-4844 support